Struct bui_backend::lowlevel::CallbackDataAndSession
[−]
[src]
pub struct CallbackDataAndSession {
pub name: String,
pub args: Value,
pub session_key: SessionKeyType,
}Callback data from a connected client.
Fields
name: String
The name of the callback sent from the client.
args: Value
The arguments of the callback sent from the client.
session_key: SessionKeyType
The session key associated with the client.