pub struct NewEventStreamConnection {
pub chunk_sender: EventChunkSender,
pub session_key: SessionKey,
pub connection_key: ConnectionKey,
pub path: String,
}Expand description
Wrap the sender to each connected event stream listener.
Fields
chunk_sender: EventChunkSenderA sink for messages send to each connection (one per client tab).
session_key: SessionKeyIdentifier for each connected session (one per client browser).
connection_key: ConnectionKeyIdentifier for each connection (one per client tab).
path: StringThe path being requested (starts with BuiService::events_prefix).